config.load_data — DarkHistory documentation

# config.load_data

`config.` `load_data`(data_type)

  Loads data from downloaded files.

  Parameters: | data_type : {‘binning’, ‘dep_tf’, ‘ics_tf’, ‘struct’, ‘hist’, ‘pppc’} Type of data to load. The options are: * ‘binning’: Default binning for all transfer functions; * ‘dep_tf’: Transfer functions for propagating photons and deposition into low-energy photons, low-energy electrons, high-energy deposition and upscattered CMB energy rate; * ‘ics_tf’: Transfer functions for ICS for scattered photons in the Thomson regime, relativistic regime, and scattered electron energy-loss spectrum; * ‘struct’: Structure formation boosts; * ‘hist’: Baseline ionization and temperature histories, and * ‘pppc’: Data from PPPC4DMID for annihilation spectra. Specify the primary channel in primary.
  Returns: | dict A dictionary of the data requested.

  See also

  `get_pppc_spec()`

#### Previous topic

config.PchipInterpolator2D

#### Next topic

darkhistory

### This Page

Show Source